
package javabeans;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;


/**Class that is used to ckeck if the values inserted from the user
 * for the tables keys already exist.
 * 
 * @author LOU10*/
public class Checker 
{
    /**PreparedStatement variable for making prepared statements to the database. */
    private PreparedStatement statement = null;    
    /**ResultSet variable for taking the results from a query to the database. */
    private ResultSet rs = null; 
    /**DataSource variable for connecting to the datasource. */
    DataSource ds = null;
    /**Connection variable for connecting to the database. */
    Connection connection = null;

    /**Public constructor for the Checker class that also initializes 
     * the connection to the datasource. */
    public Checker()
    {
        try
        {
            //connect to the datasource
            Context context = new InitialContext();        
            Context envctx = (Context) context.lookup("java:comp/env");
            this.ds = (DataSource) envctx.lookup("jdbc/test");
        } catch (NamingException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
        }
    }   
        
    /**Checks if the username inserted by the user already exists.
     * @param username The value of the username.
     * @return True if the username doesn't already exists false otherwise. */
    public boolean checkUsername(String username)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement("SELECT * FROM users WHERE username = ?");
            statement.setString(1, username);
            rs = statement.executeQuery();

            if (rs.next())
            {
                return false;
            }

            return true;
        } catch (SQLException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }
    
    /**Checks if the email inserted by the user already exists.
     * @param email The value of the email.
     * @return True if the email doesn't already exists false otherwise. */
    public boolean checkEmail(String email)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement("SELECT * FROM users WHERE email = ?");
            statement.setString(1, email);
            rs = statement.executeQuery();

            if (rs.next()) 
            {
                return false;
            }

            return true;
        } catch (SQLException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    } 
    
    /**Checks if the storage name inserted by the user already exists.
     * @param name The value of the storage name.
     * @return True if the storage name doesn't already exists false otherwise. */
    public boolean checkStorageName(String name)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement("SELECT * FROM storages WHERE name = ?");
            statement.setString(1, name);
            rs = statement.executeQuery();

            if (rs.next()) 
            {
                return false;
            }

            return true;
        } catch (SQLException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }   

    /**Checks if the combination of name and serial number inserted by the user already exists.
     * @param name The value of the product name.
     * @param serial The value of the serial number.    
     * @return True if the combination of name and serial number doesn't already exists false otherwise. */    
    public boolean checkProductKey(String name, String serial)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement("SELECT * FROM products WHERE name = ? AND serial = ?");
            statement.setString(1, name);
            statement.setString(2, serial);
            rs = statement.executeQuery();

            if (rs.next()) 
            {
                return false;
            }

            return true;
        } catch (SQLException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }
    
    /**Checks if the company name inserted by the user already exists.
     * @param comp The value of the company name.
     * @return True if the company name doesn't already exists false otherwise. */
    public boolean checkSupplierName(String comp)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement("SELECT * FROM suppliers WHERE company = ?");
            statement.setString(1, comp);
            rs = statement.executeQuery();

            if (rs.next()) 
            {
                return false;
            }

            return true;
        } catch (SQLException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }    
}
