
package javabeans;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;


/**Class of the user objects that contains their attributes 
 * and all the actions that a user can perform.
 * 
 * @author LOU10*/
public class User 
{
    private String username;
    private String password;
    private String name;
    private String surname;
    private String email;
    private String telephone;
    private String role;
    private PreparedStatement statement = null;    
    private ResultSet rs = null;    
    DataSource ds = null;
    Connection connection = null;    

    /**Public constructor for the User class that also initializes 
     * the connection to the datasource. */
    public User()
    {
        try
        {
            Context context = new InitialContext();        
            Context envctx = (Context) context.lookup("java:comp/env");
            this.ds = (DataSource) envctx.lookup("jdbc/test");
        } catch (NamingException ex)
        {
            Logger.getLogger(Checker.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
    
    /**
     *
     * @return
     */
    public String getUsername()
    {
        return username;
    }

    /**
     *
     * @return
     */
    public String getPassword()
    {
        return password;
    }

    /**
     *
     * @return
     */
    public String getName()
    {
        return name;
    }

    /**
     *
     * @return
     */
    public String getSurname()
    {
        return surname;
    }

    /**
     *
     * @return
     */
    public String getEmail()
    {
        return email;
    }

    /**
     *
     * @return
     */
    public String getTelephone()
    {
        return telephone;
    }

    /**
     *
     * @return
     */
    public String getRole()
    {
        return role;
    }

    /**
     *
     * @param username
     */
    public void setUsername(String username)
    {
        this.username = username;
    }

    /**
     *
     * @param password
     */
    public void setPassword(String password)
    {
        this.password = password;
    }

    /**
     *
     * @param name
     */
    public void setName(String name)
    {
        this.name = name;
    }

    /**
     *
     * @param surname
     */
    public void setSurname(String surname)
    {
        this.surname = surname;
    }

    /**
     *
     * @param email
     */
    public void setEmail(String email)
    {
        this.email = email;
    }

    /**
     *
     * @param telephone
     */
    public void setTelephone(String telephone)
    {
        this.telephone = telephone;
    }

    /**
     *
     * @param role
     */
    public void setRole(String role)
    {
        this.role = role;
    }    
    
    /**Sets all the user attributes at once.
     * @param username The value of the username.
     * @param password The value of the password.
     * @param name The value of the name.
     * @param surname The value of the surname.
     * @param telephone The value of the telephone.
     * @param email The value of the email.
     * @param role The value of the role.*/
    public void setAll(String username, String password, String name,
                String surname, String telephone, String email, String role)
    {
        this.username = username;
        this.password = password;
        this.name = name;
        this.surname = surname;
        this.telephone = telephone;
        this.email = email;
        this.role = role;
    }    
    
    /**Stores all the values of the user attributes to the database. */
    public void insertToDatabase()
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("INSERT INTO users(username, password, name, surname, telephone, email, role)"
            +"VALUES(?,?,?,?,?,?,?)");
            statement.setString(1, this.username);   
            statement.setString(2, this.password);
            statement.setString(3, this.name);
            statement.setString(4, this.surname);
            statement.setString(5, this.telephone);
            statement.setString(6, this.email);
            statement.setString(7, this.role);            
            statement.executeUpdate();           
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }        
    }
    
    /**Updates a desired attribute with a new value to the database.
     * @param updateParam The desired attribute to be updated.
     * @param newValue The new value of the desired attribute.
     * @param username The username of the user that wants to make the update.*/
    public void updateToDatabase(String updateParam, String newValue, String username)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if (updateParam.equals("password"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET password = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();  
                this.setPassword(newValue);
            } 
            else if (updateParam.equals("name"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET name = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();  
                this.setName(newValue);
            }
            else if (updateParam.equals("surname"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET surname = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();                 
                this.setSurname(newValue);
            }
            else if (updateParam.equals("telephone"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET telephone = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();
                this.setTelephone(newValue);
            }
            else if (updateParam.equals("email"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET email = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();
                this.setEmail(newValue);
            }   
            else if (updateParam.equals("role"))
            {
                statement = connection.prepareStatement
                ("UPDATE users SET role = ? WHERE username = ?");   
                statement.setString(1, newValue);
                statement.setString(2, username);
                statement.executeUpdate();
            }                       
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }               
    }
    
    /**Sets all the attributes according to the values that are stored to the database
     * if the username and password inserted by the user are correct.
     * @param username The value of the username inserted by the user.
     * @param password The value of the password inserted by the user.
     * @return True if the username and password inserted by the user are correct, false otherwise.*/
    public boolean retrieveFromDatabase(String username, String password)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT password FROM users WHERE username = ?");
            statement.setString(1, username);   
            rs = statement.executeQuery();
            
            if(rs.next())
            {
                if(rs.getString(1).equals(password))
                {                
                    statement = connection.prepareStatement
                    ("SELECT * FROM users WHERE username = ?");
                    statement.setString(1, username);
                    rs = statement.executeQuery();
                    rs.next();
                    
                    this.setAll(username, password, rs.getString(3), rs.getString(4), rs.getString(5),
                                rs.getString(6), rs.getString(7));
                    
                    return true;
                }
                else
                {
                    return false;
                }
            }
            else
            {              
                return false;
            }            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
        return false;
    }    
    
    /**Gets all users that are stored to the database.
     * @return A list that contains all the users on the database. */
    public List<User> getAllUsers()
    {
        List<User> users = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM users");
            rs = statement.executeQuery();
            
            while(rs.next())
            {
                User temp = new User();
                
                temp.setAll(rs.getString(1), rs.getString(2), rs.getString(3), rs.getString(4), rs.getString(5),
                            rs.getString(6), rs.getString(7));
                users.add(temp);                               
            }                   
            
            return users; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }    
        return null;
    }
    
    /**Gets a user from the database.
     * @param username The username of the desired user.
     * @return The desired user. */
    public User getUser(String username)
    {
        User user = new User();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM users WHERE username = ?");
            statement.setString(1, username);
            rs = statement.executeQuery();
            
            if(rs.next())
            {                              
                user.setAll(username, rs.getString(2), rs.getString(3), rs.getString(4), rs.getString(5),
                            rs.getString(6), rs.getString(7));                             
            }                   
            
            return user; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }    
        return null;
    }    
    
    /**Gets all the storages that are stored to the database.
     * @return A list that contains all the storages from the database. */
    public List<Storage> getAllStorages()
    {
        List<Storage> storages = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM storages");
            rs = statement.executeQuery();
            
            while(rs.next())
            {
                Storage temp = new Storage();
                
                temp.setName(rs.getString(1));
                temp.setDescription(rs.getString(2));
                temp.setOpen((Integer.parseInt(rs.getString(3)) == 0 ? false : true));
                temp.setLocation(rs.getString(4));
                
                storages.add(temp);                               
            }                   
            
            return storages; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }    
        return null;        
    }
    
    /**Creates a new storage with the desired attributes.
     * @param name The value of the desired storage name.
     * @param desc The value of the desired storage description.
     * @param open A value to show if the desired storage will be open or not.
     * @param loc The value of the desired storage location. */
    public void createNewStorage(String name, String desc, int open, String loc)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("INSERT INTO storages(name, description, open, location)"
            +"VALUES(?,?,?,?)");
            statement.setString(1, name);   
            statement.setString(2, desc);
            statement.setInt(3, open);
            statement.setString(4, loc);            
            statement.executeUpdate();          
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }    
    
    /**Gets a storage from the database.
     * @param storagename The name of the desired storage.
     * @return The desired storage. */
    public Storage getStorage(String storagename)
    {
        Storage storage = new Storage();
        
        try
        {
            connection = ds.getConnection();
            
            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM storages WHERE name = ?");
            statement.setString(1, storagename);
            rs = statement.executeQuery();
            
            if(rs.next())
            {                              
                storage.setName(rs.getString(1));                             
                storage.setDescription(rs.getString(2)); 
                storage.setOpen((rs.getInt(3) == 0 ? false : true )); 
                storage.setLocation(rs.getString(4)); 
            }                   
            
            return storage; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }  
    
    /**Gets the number of products that are stored in a storage.
     * @param storagename The name of the storage.
     * @return The number of products. */
    public int getProductsCount(String storagename)
    {
        int prcount = 0;
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT quantity FROM products WHERE storagename = ?");
            statement.setString(1, storagename);
            rs = statement.executeQuery();
            
            while(rs.next())
            {         
                prcount += rs.getInt(1);                
            }                   
            
            return prcount; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return -1;
    }    
    
    /**Updates a desired attribute of a storage with a new value to the database.
     * @param updateParam The desired attribute to be updated.
     * @param newValue The new value of the desired attribute.
     * @param storagename The name of the storage that will be updated.*/    
    public void updateStorage(String updateParam, String newValue, String storagename)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if (updateParam.equals("description"))
            {
                statement = connection.prepareStatement
                ("UPDATE storages SET description = ? WHERE name = ?");   
                statement.setString(1, newValue);
                statement.setString(2, storagename);
                statement.executeUpdate();                 
            } 
            else if (updateParam.equals("location"))
            {
                statement = connection.prepareStatement
                ("UPDATE storages SET location = ? WHERE name = ?");   
                statement.setString(1, newValue);
                statement.setString(2, storagename);
                statement.executeUpdate();                    
            }
            else if (updateParam.equals("open"))
            {                                
                statement = connection.prepareStatement
                ("UPDATE storages SET open = ? WHERE name = ?");   
                statement.setInt(1, Integer.parseInt(newValue));
                statement.setString(2, storagename);
                statement.executeUpdate();                               
            }          
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    }    
    
    /**Deletes a storage from the database.
     * @param storagename The name of the storage to be deleted. */
    public void deleteStorage(String storagename)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("DELETE FROM storages WHERE name = ?");   
            statement.setString(1, storagename);            
            statement.executeUpdate();                            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    } 
    
    /**Gets twenty products, based on the index, that a storage contains.
     * @param storagename The name of the desired storage.
     * @param index Index to take twenty products from.
     * @return A list with the products requested. */
    public List<Product> getStorageProducts(String storagename, int index)
    {
        List<Product> prList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products WHERE storagename = ? ORDER BY name LIMIT ?, 20");
            statement.setString(1, storagename);
            statement.setInt(2, index*20);
            rs = statement.executeQuery();

            while(rs.next())
            { 
                Product pr = new Product();
                
                pr.setName(rs.getString(1));                             
                pr.setSerial(rs.getString(2)); 
                pr.setDescription(rs.getString(3)); 
                pr.setTimeCreated(rs.getDate(6)); 
                pr.setTimeChanged(rs.getDate(7));
                
                prList.add(pr);
            }                   
            
            return prList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }    
        return null;
    }    
    
    /**Gets the numbers of products in a storage.
     * @param storagename The name of the desired storage.
     * @return The number of the products. */
    public int getStorageProductsCount(String storagename)
    {        
        int count;
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products WHERE storagename = ?");
            statement.setString(1, storagename);
            rs = statement.executeQuery();
            
            rs.last();
            count = rs.getRow();
            
            return count; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return -1;
    }  
    
    /**Gets the ten latest active products from a storage.
     * @param storagename The name of the desired storage.
     * @return A list of the ten latest active products. */
    public List<Product> getStorageLatestActiveProducts(String storagename)
    {
        List<Product> prList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products WHERE storagename = ? ORDER BY changed DESC LIMIT 0, 10");
            statement.setString(1, storagename);            
            rs = statement.executeQuery();

            while(rs.next())
            { 
                Product pr = new Product();
                
                pr.setName(rs.getString(1));                             
                pr.setSerial(rs.getString(2)); 
                pr.setDescription(rs.getString(3)); 
                pr.setTimeCreated(rs.getDate(6)); 
                pr.setTimeChanged(rs.getDate(7));
                
                prList.add(pr);
            }                   
            
            return prList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }  
  
    /**Creates a new product with the desired attributes.
     * @param name The value for the name of the product.
     * @param serial The value for the serial number of the product.
     * @param desc The value for the description of the product.
     * @param strname The value for the storage name the product will be stored.
     * @param quantity The value for the quantity of the product.
     * @param type The value for the type of the product.
     * @param weight The value for the weight of the product.
     * @param length The value for the length of the product.
     * @param width The value for the width of the product.
     * @param height The value for the height of the product. */
    public void createNewProduct(String name, String serial, String desc, String strname, String quantity,
                                 String type,String weight, String length, String width, String height)
    {
        try
        {
             connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("INSERT INTO products(name, serial, description, storagename, quantity, type, weight, length, width, height)"
            +"VALUES(?,?,?,?,?,?,?,?,?,?)");
            statement.setString(1, name);   
            statement.setString(2, serial);
            statement.setString(3, desc);
            statement.setString(4, strname);            
            statement.setInt(5, Integer.parseInt(quantity));
            if(type.equals("")){ statement.setString(6, null);} else{ statement.setString(6, type);}            
            if(weight.equals("")){ statement.setString(7, null);} else{ statement.setFloat(7, Float.parseFloat(weight));}
            if(length.equals("")){ statement.setString(8, null);} else{ statement.setFloat(8, Float.parseFloat(length));}
            if(width.equals("")){ statement.setString(9, null);} else{ statement.setFloat(9, Float.parseFloat(width));}
            if(height.equals("")){ statement.setString(10, null);} else{ statement.setFloat(10, Float.parseFloat(height));}
            statement.executeUpdate();          
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }  
    
    /**Gets twenty products, based on the index, ordered by name.
     * @param index Index to take twenty products from.
     * @return A list with the products requested. */
    public List<Product> getAllProducts(int index)
    {
        List<Product> prList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products ORDER BY name LIMIT ?, 20");
            statement.setInt(1, index*20);
            rs = statement.executeQuery();

            while(rs.next())
            { 
                Product pr = new Product();
                
                pr.setName(rs.getString(1));                             
                pr.setSerial(rs.getString(2)); 
                pr.setDescription(rs.getString(3)); 
                pr.setTimeCreated(rs.getDate(6)); 
                pr.setTimeChanged(rs.getDate(7));
                
                prList.add(pr);
            }                   
            
            return prList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }    
    
    /**Gets the number of all products on the database.
     * @return The number of the products. */
    public int getAllProductsCount()
    {        
        int count;
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products");
            rs = statement.executeQuery();
            
            rs.last();
            count = rs.getRow();
            
            return count; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return -1;
    }    
    
    /**Gets the product with the desired name and serial number.
     * @param name The desired product name.
     * @param serial The desired serial number.
     * @return The desired product. */
    public Product getProduct(String name, String serial)
    {
        Product prod = new Product();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM products WHERE name = ? AND serial = ?");
            statement.setString(1, name);
            statement.setString(2, serial);
            rs = statement.executeQuery();

            if(rs.next())
            {                               
                prod.setName(name);                             
                prod.setSerial(serial); 
                prod.setDescription(rs.getString(3));
                prod.setStorageName(rs.getString(4));
                prod.setQuantity(Integer.parseInt(rs.getString(5)));
                prod.setTimeCreated(rs.getDate(6)); 
                prod.setTimeChanged(rs.getDate(7));
                prod.setType(rs.getString(8));
                if(rs.getString(9) == null){prod.setWeight(-0.1f);}else{prod.setWeight(Float.parseFloat(rs.getString(9)));}
                if(rs.getString(10) == null){prod.setLength(-0.1f);}else{prod.setLength(Float.parseFloat(rs.getString(10)));}
                if(rs.getString(11) == null){prod.setWidth(-0.1f);}else{prod.setWidth(Float.parseFloat(rs.getString(11)));}
                if(rs.getString(12) == null){prod.setHeight(-0.1f);}else{prod.setHeight(Float.parseFloat(rs.getString(12)));}
            }                   
            
            return prod; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }    
      
    /**Gets the company names from all the suppliers in the database.
     * @return A list with all the supplier names. */
    public List<String> getAllSuppliersNames()
    {
        List<String> supList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT company FROM suppliers");            
            rs = statement.executeQuery();

            while(rs.next())
            { 
                String temp = rs.getString(1);
                
                supList.add(temp);
            }                   
            
            return supList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }        
    
    /**Gets all the supplier names that sell a desired product.
     * @param prname The name of the desired product.
     * @param prserial The serial number of the desired product.
     * @return A list with the names of the suppliers that sell the product. */
    public List<String> getProductSuppliersNames(String prname, String prserial)
    {
        List<String> psupList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT suppliercompany FROM prices WHERE productname = ? AND productserial = ?"); 
            statement.setString(1, prname);
            statement.setString(2, prserial);
            rs = statement.executeQuery();

            while(rs.next())
            { 
                String temp = rs.getString(1);
                
                psupList.add(temp);
            }                   
            
            return psupList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }  
            
    /**Updates a desired attribute of a product with a new value to the database.
     * @param updateParam The desired attribute to be updated.
     * @param newValue The new value of the desired attribute.
     * @param prname The name of the product to be updated.
     * @param prserial The serial number of the product to be updated.*/
    public void updateProduct(String updateParam, String newValue, String prname, String prserial)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if (updateParam.equals("description"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET description = ? WHERE name = ? AND serial = ?");   
                statement.setString(1, newValue);
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                  
            } 
            else if (updateParam.equals("storagename"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET storagename = ? WHERE name = ? AND serial = ?");   
                statement.setString(1, newValue);
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                    
            }
            else if (updateParam.equals("quantity"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET quantity = ? WHERE name = ? AND serial = ?");   
                statement.setInt(1, Integer.parseInt(newValue));
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                   
            }  
            else if (updateParam.equals("type"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET type = ? WHERE name = ? AND serial = ?");   
                statement.setString(1, newValue);
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                    
            } 
            else if (updateParam.equals("weight"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET weight = ? WHERE name = ? AND serial = ?");   
                statement.setFloat(1, Float.parseFloat(newValue));
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                    
            } 
            else if (updateParam.equals("length"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET length = ? WHERE name = ? AND serial = ?");   
                statement.setFloat(1, Float.parseFloat(newValue));
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                   
            }  
            else if (updateParam.equals("width"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET width = ? WHERE name = ? AND serial = ?");   
                statement.setFloat(1, Float.parseFloat(newValue));
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                    
            } 
            else if (updateParam.equals("height"))
            {
                statement = connection.prepareStatement
                ("UPDATE products SET height = ? WHERE name = ? AND serial = ?");   
                statement.setFloat(1, Float.parseFloat(newValue));
                statement.setString(2, prname);
                statement.setString(3, prserial);
                statement.executeUpdate();                    
            }             
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    }    
        
    /**Deletes a product from the database.
     * @param prname The name of the product to be deleted.
     * @param prserial The serial number of the product to be deleted. */
    public void deleteProduct(String prname, String prserial)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("DELETE FROM products WHERE name = ? AND serial = ?");   
            statement.setString(1, prname);            
            statement.setString(2, prserial);
            statement.executeUpdate();                            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    } 
    
    /**Adds a supplier and his price to a product.
     * @param prname The name of the desired product.
     * @param prserial The serial number of the desired product.
     * @param supname The name of the desired supplier.
     * @param price The desired price for the product to the supplier. */
    public void addProductSupplier(String prname, String prserial, String supname, String price)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("INSERT INTO prices(productname, productserial, suppliercompany, price)"
            +"VALUES(?,?,?,?)");
            statement.setString(1, prname);            
            statement.setString(2, prserial);
            statement.setString(3, supname);
            statement.setFloat(4, Float.parseFloat(price));
            statement.executeUpdate();                            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    }
    
    /**Gets all the suppliers and their prices of a product. 
     * @param prname The name of the desired product.
     * @param prserial The serial number of the desired product.
     * @return A list of arrays with two strings, the first 
     * is the suppliers name and the second the suppliers price. */
    public List<String[]> getProductSuppliers(String prname, String prserial)
    {
        List<String[]> psupList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT suppliercompany, price FROM prices WHERE productname = ? AND productserial = ?"); 
            statement.setString(1, prname);
            statement.setString(2, prserial);
            rs = statement.executeQuery();

            while(rs.next())
            { 
                String[] temp = new String[2];
                
                temp[0] = rs.getString(1);
                temp[1] = rs.getString(2);
                
                psupList.add(temp);
            }                   
            
            return psupList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;        
    }
    
    /**Searches the database for the product matching the criteria based on a category.
     * @param category The desired category that the search will be performed.
     * @param criteria The criteria is the keyword to be searched.
     * @return A list of arrays with two strings, the first 
     * is the products name and the second the products serial number. */
    public List<String[]> searchProducts(String category, String criteria)
    {
        List<String[]> prList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if(category.equals("name"))
            {
                statement = connection.prepareStatement
                ("SELECT name, serial FROM products WHERE name LIKE ?"); 
                statement.setString(1, "%"+criteria+"%");
                rs = statement.executeQuery();
            } 
            if(category.equals("serial"))
            {
                statement = connection.prepareStatement
                ("SELECT name, serial FROM products WHERE serial LIKE ?"); 
                statement.setString(1, "%"+criteria+"%");
                rs = statement.executeQuery();
            } 
            if(category.equals("description"))
            {
                statement = connection.prepareStatement
                ("SELECT name, serial FROM products WHERE description LIKE ?"); 
                statement.setString(1, "%"+criteria+"%");
                rs = statement.executeQuery();
            } 
            if(category.equals("suppliercompany"))
            {
                statement = connection.prepareStatement
                ("SELECT productname, productserial FROM prices WHERE suppliercompany LIKE ?"); 
                statement.setString(1, "%"+criteria+"%");
                rs = statement.executeQuery();
            }             
            
            while(rs.next())
            { 
                String[] temp = new String[2];

                temp[0] = rs.getString(1);
                temp[1] = rs.getString(2);

                prList.add(temp);
            }                   

            return prList;                            
            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;        
    }    
        
    /**Creates a new supplier with the desired attributes.
     * @param company The value for the company name.
     * @param name The value for the name.
     * @param surname The value for the surname.
     * @param afm The value for the afm.
     * @param address The value for the address.
     * @param telephone The value for the telephone.
     * @param email The value for the email.*/
    public void createNewSupplier(String company, String name, String surname, String afm,
                              String address, String telephone, String email)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("INSERT INTO suppliers(company, name, surname, afm, address, telephone, email)"
            +"VALUES(?,?,?,?,?,?,?)");
            statement.setString(1, company);   
            statement.setString(2, name);
            statement.setString(3, surname);
            statement.setString(4, afm);            
            statement.setString(5, address);            
            statement.setString(6, telephone);            
            statement.setString(7, email);            
            statement.executeUpdate();          
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }
    }  

    /**Gets all suppliers from the database.
     * @return A list with all the suppliers. */
    public List<Supplier> getAllSuppliers()
    {
        List<Supplier> supList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM suppliers");            
            rs = statement.executeQuery();

            while(rs.next())
            { 
                Supplier temp = new Supplier();
                
                temp.setCompany(rs.getString(1));
                temp.setName(rs.getString(2));
                temp.setSurname(rs.getString(3));
                temp.setAfm(rs.getString(4));
                temp.setAddress(rs.getString(5));
                temp.setTelephone(rs.getString(6));
                temp.setEmail(rs.getString(7));
                
                supList.add(temp);
            }                   
            
            return supList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }
    
    /**Gets the supplier with the desired company name.
     * @param company The company name of the desired supplier.
     * @return The desired supplier. */
    public Supplier getSupplier(String company)
    {
        Supplier sup = new Supplier();
        
        try
        {
            connection = ds.getConnection();
            
            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM suppliers WHERE company = ?");
            statement.setString(1, company);
            rs = statement.executeQuery();
            
            if(rs.next())
            {                              
                sup.setCompany(rs.getString(1));
                sup.setName(rs.getString(2));
                sup.setSurname(rs.getString(3));
                sup.setAfm(rs.getString(4));
                sup.setAddress(rs.getString(5));
                sup.setTelephone(rs.getString(6));
                sup.setEmail(rs.getString(7));
            }                   
            
            return sup; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    }

    /**Gets the number of products that a supplier sells.
     * @param company The company name of the desired supplier.
     * @return The number of products. */
    public int getSuppliersProductsCount(String company)
    {
        int prcount = 0;
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM prices WHERE suppliercompany = ?");
            statement.setString(1, company);
            rs = statement.executeQuery();
            
            while(rs.next())
            {         
                prcount++;                
            }                   
            
            return prcount; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return -1;
    }
    
    /**Gets twenty products, based on the index, that the supplier sells. 
     * @param company The company name of the desired supplier.
     * @param index Index to take twenty products from.
     * @return A list of arrays with three strings, the first 
     * is the products name, the second the products serial number 
     * and the third the products price. */
    public List<String[]> getSupplierProducts(String company, int index)
    {
        List<String[]> prList = new ArrayList();
        
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("SELECT * FROM prices WHERE suppliercompany = ? ORDER BY productname LIMIT ?, 20");
            statement.setString(1, company);
            statement.setInt(2, index*20);
            rs = statement.executeQuery();

            while(rs.next())
            { 
                String[] pr = new String[3];

                pr[0] = rs.getString(1);
                pr[1] = rs.getString(2);
                pr[2] = rs.getString(4);
                
                prList.add(pr);
            }                   
            
            return prList; 
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);            
        } finally
        {
            try
            {
                if (rs != null)
                {
                    rs.close();
                }
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }     
        return null;
    } 
    
    /**Updates a desired attribute of a supplier with a new value to the database.
     * @param updateParam The desired attribute to be updated.
     * @param newValue The new value of the desired attribute.
     * @param company The company name of the supplier to be updated.
     */
    public void updateSupplier(String updateParam, String newValue, String company)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if (updateParam.equals("name"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET name = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                  
            } 
            else if (updateParam.equals("surname"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET surname = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                
            }
            else if (updateParam.equals("afm"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET afm = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                 
            }
            else if (updateParam.equals("address"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET address = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                 
            }
            else if (updateParam.equals("telephone"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET telephone = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                 
            }
            else if (updateParam.equals("email"))
            {
                statement = connection.prepareStatement
                ("UPDATE suppliers SET email = ? WHERE company = ?");   
                statement.setString(1, newValue);
                statement.setString(2, company);
                statement.executeUpdate();                 
            }            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    }    

    /**Deletes a supplier from the database.
     * @param company The company name of the supplier to be deleted. */
    public void deleteSupplier(String company)
    {
        try
        {
            connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            statement = connection.prepareStatement
            ("DELETE FROM suppliers WHERE company = ?");   
            statement.setString(1, company);            
            statement.executeUpdate();                            
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } finally
        {
            try
            {
                if (statement != null)
                {
                    statement.close();
                }
                if (connection != null)
                {
                    connection.close();
                }                
            }catch (SQLException ex)
            {
                    Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
            }              
        }                
    }     
}
