
package javabeans;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;


/**Class of the user roles objects that contains a map with the 
 * available roles of the users with their rights and the available actions for the roles.
 * 
 * @author LOU10*/
public class UsersRoles
{
    /**Map that contains the users roles as key and a three element 
     * array with the rights for each section.The first element contains the storages rights, 
     * the second the product rights and the third the supplier rights. */
    private Map<String, int[]> roles;

    /**Public consructor of the class that initializes the map and retrieves
     * the roles and their rights from the database. */
    public UsersRoles()
    {
        roles = new HashMap();
        this.retrieveFromDatabase();
    }

    /**
     *
     * @return
     */
    public Map<String, int[]> getRoles()
    {
        return roles;
    }

    /**
     *
     * @param roles
     */
    public void setRoles(Map<String, int[]> roles)
    {
        this.roles = roles;
    }
    
    /**Creates a new role in the database.
     * @param role The value of the role name.
     * @param str The value for the storage rights.
     * @param prr The value for the product rights.
     * @param sur The value for the supplier rights. */
    public void insertToDatabase(String role, int str, int prr, int sur)
    {
        try
        {
            Context context = new InitialContext();
            Context envctx = (Context) context.lookup("java:comp/env");
            DataSource ds = (DataSource) envctx.lookup("jdbc/test");
            Connection connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            PreparedStatement statement = connection.prepareStatement
            ("INSERT INTO roles(role, storagerights, productrights, supplyrights)"
            +"VALUES(?,?,?,?)");
            statement.setString(1, role);   
            statement.setString(2, String.valueOf(str));
            statement.setString(3, String.valueOf(prr));
            statement.setString(4, String.valueOf(sur));         
            statement.executeUpdate();
            statement.close();   
            
            int[] rights = new int[3]; 
            rights[0] = str;
            rights[1] = prr;
            rights[2] = sur;
            this.roles.put(role, rights);
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } catch (NamingException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
        
    /**Updates the desired rights of a role with a new value to the database.
     * @param updateParam The desired rights to be updated.
     * @param newValue The new value of the desired rights.
     * @param role The name of the role that will be updated.*/
    public void updateToDatabase(String updateParam, int newValue, String role)
    {
        try
        {
            Context context = new InitialContext();
            Context envctx = (Context) context.lookup("java:comp/env");
            DataSource ds = (DataSource) envctx.lookup("jdbc/test");
            Connection connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            if (updateParam.equals("storagerights"))
            {
                PreparedStatement statement = connection.prepareStatement
                ("UPDATE roles SET storagerights = ? WHERE role = ?");   
                statement.setInt(1, newValue);
                statement.setString(2, role);
                statement.executeUpdate();
                statement.close();  
                
                this.roles.get(role)[0] = newValue;
            } 
            else if (updateParam.equals("productrights"))
            {
                PreparedStatement statement = connection.prepareStatement
                ("UPDATE roles SET productrights = ? WHERE role = ?");   
                statement.setInt(1, newValue);
                statement.setString(2, role);
                statement.executeUpdate();
                statement.close();  
                
                this.roles.get(role)[1] = newValue;
            } 
            else if (updateParam.equals("supplyrights"))
            {
                PreparedStatement statement = connection.prepareStatement
                ("UPDATE roles SET supplyrights = ? WHERE role = ?");   
                statement.setInt(1, newValue);
                statement.setString(2, role);
                statement.executeUpdate();
                statement.close();  
                
                this.roles.get(role)[2] = newValue;
            }             
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } catch (NamingException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        }               
    }    
    
    /**Retrieves from the database the roles and their rights and stores them into the map. */
    public void retrieveFromDatabase()
    {
        try
        {
            Context context = new InitialContext();
            Context envctx = (Context) context.lookup("java:comp/env");
            DataSource ds = (DataSource) envctx.lookup("jdbc/test");
            Connection connection = ds.getConnection();

            if (connection == null) {
                throw new SQLException("Error establishing connection!");
            }

            PreparedStatement statement = connection.prepareStatement
            ("SELECT * FROM roles");                      
            ResultSet rs = statement.executeQuery();
            
            while(rs.next())
            {
                int[] rights = new int[3]; 
                rights[0] = rs.getInt(2);
                rights[1] = rs.getInt(3);
                rights[2] = rs.getInt(4);
                this.roles.put(rs.getString(1), rights);
            }
            
            statement.close();  
            rs.close();
            
        } catch (SQLException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        } catch (NamingException ex)
        {
            Logger.getLogger(User.class.getName()).log(Level.SEVERE, null, ex);
        }        
    }
}
